# EddyMotionCorrection

Open-source eddy-current and head-motion correction for diffusion MRI, an extension of SHOREline (Cieslak, 2020) to multiple diffusion models.

![Before and After](docs/assets/emc_reg.gif)
